### Content

This work is a derivative from the Atlanta sample (Liu et al., 2009) found in the 
[1000 functional connectome project](http://fcon_1000.projects.nitrc.org/fcpClassic/FcpTable.html) (Biswal et al., 2010), 
originally released under Creative Commons -- Attribution Non-Commercial. It includes preprocessed resting-state functional 
magnetic resonance images for 19 healthy subjects. Time series are packaged in a series of .mat matlab/octave (HDF5) files, 
one per subject. For each subject, an array featuring about 200 time points for 116 brain regions from the AAL template is available. 
The Atlanta AAL preprocessed time series release more specifically contains the following files:
 * README.md: a markdown (text) description of the release.
 * brain_rois.nii.gz: a 3D nifti volume of the AAL template at 3 mm isotropic resolution, in the MNI non-linear 2009a symmetric space (http://www.bic.mni.mcgill.ca/ServicesAtlases/ICBM152NLin2009). Region number I is filled with Is (background is filled with 0s).
 * labels_aal.mat: a .mat file with two variables: rois_aal(i) is the numrical ID of the i-th region in the AAL template (e.g. 2001, 2002, 2101, etc). labels_all{i} is a string label for the i-th region (e.g. 'Precentral_L', 'Precentral_R', etc). 
 * tseries_rois_SUBJECT_session1_run1.mat: a matlab/octave file for each subject.

Each tseries file contains the following variables:
 * confounds: a TxK array. Each row corresponds to a time sample, and each column to one confound that was regressed out from the time series during preprocessing.
 * labels_confounds: cell of strings. Each entry is the label of a confound that was regressed out from the time series.
 * mask_suppressed: a T2x1 vector. T2 is the number of time samples in the raw time series (before preprocessing), T2=205. Each entry corresponds to a time sample, and is 1 if the corresponding sample was removed due to excessive motion (or to wait for magnetic equilibrium at the beginning of the series). Samples that were kept are tagged with 0s.
 * time_frames: a Tx1 vector. Each entry is the time of acquisition (in s) of the corresponding volume.
 * tseries: a TxN array, where each row is a time sample and each column a region (N=483, numbered as in brain_rois.nii.gz). Note that the number of time samples may vary, as some samples have been removed if tagged with excessive motion.

### Preprocessing

The datasets were analysed using the NeuroImaging Analysis Kit (NIAK https://github.com/SIMEXP/niak) version 0.6.5c. The parameters of a rigid body motion were first estimated at each time frame of the fMRI dataset (no correction of inter-slice difference in acquisition time was applied). The median volume of the fMRI time series was coregistered with a T1 individual scan using Minctracc9 (Collins et al., 1994), which was itself transformed to the Montreal Neurological Institute (MNI) non-linear template (Fonov et al., 2011) using the CIVET10 pipeline (Zijdenbos et al., 2002). The rigid-body transform, fMRI-to-T1 transform and T1-to-stereotaxic transform were all combined, and the functional volumes were resampled in the MNI space at a 3 mm isotropic resolution. The “scrubbing” method of Power et al. (2012) was used to remove the volumes with excessive motion (frame displacement
greater than 0.5). The following nuisance parameters were regressed out from the time series at each voxel: slow time drifts (basis of discrete cosines with a 0.01 Hz high-pass cut-off), average signals in conservative masks of the white matter and the lateral ventricles as well as the first principal components (95% energy) of the six rigid-body motion parameters and their squares (Giove et al., 2009). The fMRI volumes were then spatially smoothed with a 6 mm isotropic Gaussian blurring kernel. Because some of
the measures considered in this paper are poorly conditioned when the number of spatial locations is larger than the number of time points (BIC and
InfoMut), the fMRI time series were spatially averaged on each of the areas of the AAL brain template (Tzourio-Mazoyer et al., 2002). To further reduce
the spatial dimension, only the 81 cortical AAL areas were included in the analysis (excluding the cerebellum, the basal ganglia and the thalamus). The clustering methods were applied to these regional time series. Note that 8 subjects were excluded because there was not enough time points left after scrubbing (a minimum number of 190 volumes was selected as acceptable), and one additional subject had to be excluded because the quality of the T1-fMRI coregistration was substandard (by visual inspection). A total of
19 subjects was thus actually used in this analysis.

### References

Bellec, P., Rosa-Neto, P., Lyttelton, O. C., Benali, H., Evans, A. C., Jul. 2010.
Multi-level bootstrap analysis of stable clusters in resting-state fMRI. Neu-
roImage 51 (3), 1126–1139.
URL http://dx.doi.org/10.1016/j.neuroimage.2010.02.082

Biswal, B. B. et al., 2010. Toward discovery
science of human brain function. Proceedings of the National Academy of
Sciences of the U.S.A. 107 (10), 4734–4739.

Collins, D. L., Evans, A. C., 1997. Animal: validation and applications of nonlin-
ear registration-based segmentation. International Journal of Pattern Recog-
nition and Artificial Intelligence 11, 1271–1294.

Fonov, V., Evans, A. C., Botteron, K., Almli, C. R., McKinstry, R. C., Collins,
D. L., Jan. 2011. Unbiased average age-appropriate atlases for pediatric stud-
ies. NeuroImage 54 (1), 313–327.
URL http://dx.doi.org/10.1016/j.neuroimage.2010.07.033

Giove, F., Gili, T., Iacovella, V., Macaluso, E., Maraviglia, B., Oct. 2009.
Images-based suppression of unwanted global signals in resting-state func-
tional connectivity studies. Magnetic resonance imaging 27 (8), 1058–1064.
URL http://dx.doi.org/10.1016/j.mri.2009.06.004

Liu, H., Stufflebeam, S. M., Sepulcre, J., Hedden, T., Buckner, R. L., 2009.
Evidence from intrinsic activity that asymmetry of the human brain is
controlled by multiple factors. Proceedings of the National Academy of
Sciences of the U.S.A. 106 (48), 20499–20503.

Power, J. D., Barnes, K. A., Snyder, A. Z., Schlaggar, B. L., Petersen, S. E.,
Feb. 2012. Spurious but systematic correlations in functional connectivity
MRI networks arise from subject motion. NeuroImage 59 (3), 2142–2154.
URL http://dx.doi.org/10.1016/j.neuroimage.2011.10.018

Tzourio-Mazoyer, N., Landeau, B., Papathanassiou, D., Crivello, F., Etard,
O., Delcroix, N., Mazoyer, B., Joliot, M., 2002. Automated anatomical
labeling of activations in SPM using a macroscopic anatomical parcellation
of the MNI MRI single-subject brain. NeuroImage 15, 273–289.

Zijdenbos, A. P., Forghani, R., Evans, A. C., 2002. Automatic ”pipeline”
analysis of 3-D MRI data for clinical trials: application to multiple sclerosis.
IEEE Transactions on Medical Imaging 21 (10), 1280–1291.

### Other derivatives

This dataset was used in a publication:
http://arxiv.org/abs/1501.05194
    
